@@ -4,6 +4,7 @@
 class Colors:
     def __init__(self):
         pass
+    
     # THESE ARE THE CODES FOR COLORS IN LINUX TERMINAL JUST LIKE HTML
     # BG = BACKGROUND
     # BR = BRIGHT
@@ -15,6 +16,8 @@ class Colors:
     YELLOW = "\u001b[33m"
     GREEN = "\033[0;32m"
     MAGENTA = "\u001b[35m"
+    WHITE = "\u001b[37m"
+    BLACK =  "\u001b[30m"
     BR_BLACK = "\u001b[30;1m"
     BR_RED = "\u001b[31;1m"
     BR_GREEN = "\u001b[32;1m"
